@@ -49,9 +49,7 @@ class WindowTabs(base._TextBox):
         hook.subscribe.client_name_updated(self.update)
         hook.subscribe.focus_change(self.update)
         hook.subscribe.float_change(self.update)
-
-    def button_press(self, x, y, button):
-        self.bar.screen.group.cmd_next_window()
+        self.add_callbacks({'Button1': self.bar.screen.group.cmd_next_window})
 
     def update(self, *args):
         names = []
